const downloadGit = require('download-git-repo')
const ora = require('ora')
const inquirer = require('inquirer')
const fs = require('fs')
const chalk = require('chalk')
const logSymbols = require('log-symbols')

module.exports = async (agr) => {
  let tplName = agr[0]
  let projectName = agr[1]
  //本地不存在同名目录
  if (!fs.existsSync(projectName)) {
    // 可选式交互
    inquirer.prompt([
      {
        name: "description",
        message: '请输入项目描述'
      },
      {
        name: 'author',
        message: '请输入作者名称'
      }
    ]).then(async (answer) => {
      // 显示loading动画
      let loading = ora('下载模版文件中...')
      loading.start()
      // 拉取远程模版
      let downTplFromGit = async (tplName, projectName) => {
        let gitUrl = `listentime/${tplName}`
        return new Promise((resolve, reject) => {
          //projectName 为下载到的本地目录
          downloadGit(gitUrl, projectName, (err) => {
            if (err) {
              reject(err);
            }
            resolve();
          });
        });
      }
      downTplFromGit(tplName, projectName).then(() => {
        loading.succeed()
        const targetName = `${projectName}/package.json`;
        if (fs.existsSync(targetName)) {
          const data = fs.readFileSync(targetName).toString();
          let json = JSON.parse(data);
          json.name = projectName;
          json.author = answer.author;
          json.description = answer.description;
          //修改项目文件夹中 package.json 文件
          fs.writeFileSync(targetName, JSON.stringify(json, null, '\t'), 'utf-8');
          console.log(logSymbols.success, chalk.green('项目初始化完成!'));
        }
      }, (err) => {
        // console.log(err)
        if (err.statusCode === 404) {
          loading.fail()
          console.log(`${logSymbols.error}${chalk.red('不存在的模版文件，请联系开发者')}`)
        }
      })
    })
  } else {
    console.log(`${logSymbols.error}${chalk.red('项目已存在')}`)
  }

}